@@ -4,7 +4,7 @@
 from ujson import loads
 from tornado.gen import coroutine
 
-from holmes.models import Limiter, User
+from holmes.models import Limiter
 from holmes.handlers import BaseHandler
 
 
@@ -41,24 +41,20 @@ class LimiterHandler(BaseHandler):
 
     @coroutine
     def post(self):
-        access_token = self.request.headers.get('X-AUTH-HOLMES', None)
-
-        if self.is_empty_access_token(access_token):
-            return
-
-        result = yield User.authenticate(access_token, self.application)
-
-        if self.is_unauthorized_user(result):
+        if not self.validate_superuser():
             return
 
         post_data = loads(self.request.body)
         url = post_data.get('url', None)
-        connections = self.application.config.DEFAULT_NUMBER_OF_CONCURRENT_CONNECTIONS
+        connections = self.config.DEFAULT_NUMBER_OF_CONCURRENT_CONNECTIONS
         value = post_data.get('value', connections)
 
         if not url and not value:
             self.set_status(400)
-            self.write_json({'reason': 'Not url or value', 'description': self._('Not url or value')})
+            self.write_json({
+                'reason': 'Not url or value',
+                'description': self._('Not url or value')
+            })
             return
 
         result = Limiter.add_or_update_limiter(self.db, url, value)
@@ -69,21 +65,14 @@ class LimiterHandler(BaseHandler):
 
     @coroutine
     def delete(self, limiter_id=None):
+        if not self.validate_superuser():
+            return
+
         if not limiter_id:
             self.set_status(400)
             self.write_json({'reason': 'Invalid data', 'description': self._('Invalid data')})
             return
 
-        access_token = self.request.headers.get('X-AUTH-HOLMES', None)
-
-        if self.is_empty_access_token(access_token):
-            return
-
-        result = yield User.authenticate(access_token, self.application)
-
-        if self.is_unauthorized_user(result):
-            return
-
         limiter = Limiter.by_id(limiter_id, self.db)
 
         if not limiter or not limiter.id:
